@@ -15,7 +15,7 @@
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
   *******************************************************************************/  
 
@@ -26,22 +26,19 @@ player::player()
   computer=false;
   score=0;
   reset();
-  dir=Up;
+  dir=Directions::Up;
+  last_dir=Directions::None;
 }
 
 
 void player::reset()
 {
-  
  alive=true;
  accelerated=false;
  if(computer)
    keyPressed=true;
  else
    keyPressed=false;
-
-
-
 }
 
 void player::setCoordinates(int x, int y)
@@ -50,13 +47,11 @@ void player::setCoordinates(int x, int y)
   yCoordinate=y;
 }
 
-void player::setComputer(bool computer)
+void player::setComputer(bool isComputer)
 {
-  this->computer=computer;
+  computer=isComputer;
   if(computer)
     keyPressed=true;
   else keyPressed=false;
 }
 
-
-
