@@ -17,20 +17,20 @@
     Boston, MA 02111-1307, USA.
 */
 /*
-    $Id: kgamemisc.h,v 1.2 2001/07/09 17:28:27 andreas Exp $
+    $Id: kgamemisc.h,v 1.4 2005/01/11 12:51:21 mlaurent Exp $
 */
-#ifndef __KGAMEMSIC_H__
+#ifndef __KGAMEMISC_H__
 #define __KGAMEMISC_H__
 
 #include <qstring.h>
-
+#include <kdemacros.h>
 class KGameMiscPrivate;
 /**
  * This class contains several (usually static) functions I really did not know
  * a class for. If you know a class for any of these member s please drop one of
  * the above copyright holders a mail (or just kde-games-devel@kde.org)
  **/
-class KGameMisc
+class KDE_EXPORT KGameMisc
 {
 public:
 	KGameMisc();
