@@ -16,23 +16,18 @@
  ***************************************************************************/
 
 // include files for QT
-#include <qdir.h>
-//#include <qprinter.h>
-//#include <qpainter.h>
 #include <qprogressdialog.h>
 
 // include files for KDE
-#include <kstddirs.h>
-#include <kiconloader.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
-#include <kmenubar.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <khelpmenu.h>
 #include <kstdaction.h>
 #include <kaction.h>
-
+#include <kdebug.h>
 
 // application specific includes
 #include "lskat.h"
@@ -40,18 +35,15 @@
 #include "lskatdoc.h"
 #include "namedlg.h"
 #include "networkdlg.h"
-#include "aboutdlg.h"
-#include "movielabel.h"
 #include "msgdlg.h"
 #include <kcarddialog.h>
 
-
 #include <stdlib.h>
+#include <kstatusbar.h>
 
 #define ACTION(x)   (actionCollection()->action(x))
 #define ID_STATUS_MSG               1003
 #define ID_STATUS_MOVER              1002
-#define ID_STATUS_TIME               1001
 
 LSkatApp::LSkatApp() : KMainWindow(0)
 {
@@ -69,15 +61,15 @@ LSkatApp::LSkatApp() : KMainWindow(0)
   // call inits to invoke all other construction parts
   initGUI();
   initStatusBar();
-  setHelpMenuEnabled(false);
+  
+  setupGUI(KMainWindow::StatusBar | Save);
   createGUI(QString::null, false);
 
   initDocument();
   initView();
 
-  readOptions();
+  doc->ReadConfig(config);
 
-  
   // Needs to be after readOptions as we read in default paths
   doc->LoadGrafix(mGrafix);
 
@@ -98,7 +90,6 @@ LSkatApp::LSkatApp() : KMainWindow(0)
 
   // better be last in init
   checkMenus();
-
 }
 
 LSkatApp::~LSkatApp()
@@ -125,14 +116,8 @@ void LSkatApp::checkMenus(int menu)
     {
       disableAction("send_message");
     }
-
   }
-  if (!menu || (menu&CheckViewMenu))
-  {
-    if (statusBar()->isHidden()) ((KToggleAction*)ACTION("show_statusbar"))->setChecked(false);
-    else ((KToggleAction*)ACTION("show_statusbar"))->setChecked(true);
-  }
-
+  
   if (!menu || (menu&CheckOptionsMenu))
   {
     ((KSelectAction *)ACTION("startplayer"))->setCurrentItem(doc->GetStartPlayer());
@@ -172,7 +157,7 @@ void LSkatApp::checkMenus(int menu)
 void LSkatApp::initGUI()
 {
   QStringList list;
-  
+
   (void)KStdAction::openNew(this, SLOT(slotFileNew()), actionCollection(), "new_game");
   ACTION("new_game")->setStatusText(i18n("Starting a new game..."));
   ACTION("new_game")->setWhatsThis(i18n("Starting a new game..."));
@@ -180,7 +165,7 @@ void LSkatApp::initGUI()
                       actionCollection(), "end_game");
   ACTION("end_game")->setStatusText(i18n("Ending the current game..."));
   ACTION("end_game")->setWhatsThis(i18n("Aborts a currently played game. No winner will be declared."));
-  (void)new KAction(i18n("&Clear Statistics..."),"flag", 0, this, SLOT(slotFileStatistics()),
+  (void)new KAction(i18n("&Clear Statistics"),"flag", 0, this, SLOT(slotFileStatistics()),
                       actionCollection(), "clear_statistics");
   ACTION("clear_statistics")->setStatusText(i18n("Delete all time statistics..."));
   ACTION("clear_statistics")->setWhatsThis(i18n("Clears the all time statistics which is kept in all sessions."));
@@ -192,21 +177,16 @@ void LSkatApp::initGUI()
   ACTION("game_exit")->setStatusText(i18n("Exiting..."));
   ACTION("game_exit")->setWhatsThis(i18n("Quits the program."));
 
-  (void)new KToggleAction(i18n("&Show Statusbar"),0,this,SLOT(slotViewStatusBar()),
-                      actionCollection(), "show_statusbar");
-  ACTION("show_statusbar")->setStatusText(i18n("Toggle the statusbar..."));
-  ACTION("show_statusbar")->setWhatsThis(i18n("Toggle the statusbar..."));
-
-  (void)new KSelectAction(i18n("Startplayer"),0,this,SLOT(slotStartplayer()),
+  (void)new KSelectAction(i18n("Starting Player"),0,this,SLOT(slotStartplayer()),
                       actionCollection(), "startplayer");
-  ACTION("startplayer")->setStatusText(i18n("Changing startplayer..."));
+  ACTION("startplayer")->setStatusText(i18n("Changing starting player..."));
   ACTION("startplayer")->setWhatsThis(i18n("Chooses which player begins the next game."));
   list.clear();
   list.append(i18n("Player &1"));
   list.append(i18n("Player &2"));
   ((KSelectAction *)ACTION("startplayer"))->setItems(list);
 
-  (void)new KSelectAction(i18n("Player &1 played by"),0,this,SLOT(slotPlayer1By()),
+  (void)new KSelectAction(i18n("Player &1 Played By"),0,this,SLOT(slotPlayer1By()),
                       actionCollection(), "player1");
   ACTION("player1")->setStatusText(i18n("Changing who plays player 1..."));
   ACTION("player1")->setWhatsThis(i18n("Changing who plays player 1..."));
@@ -215,7 +195,7 @@ void LSkatApp::initGUI()
   list.append(i18n("&Computer"));
   list.append(i18n("&Remote"));
   ((KSelectAction *)ACTION("player1"))->setItems(list);
-  (void)new KSelectAction(i18n("Player &2 played by"),0,this,SLOT(slotPlayer2By()),
+  (void)new KSelectAction(i18n("Player &2 Played By"),0,this,SLOT(slotPlayer2By()),
                       actionCollection(), "player2");
   ACTION("player1")->setStatusText(i18n("Changing who plays player 2..."));
   ACTION("player1")->setWhatsThis(i18n("Changing who plays player 2..."));
@@ -230,11 +210,11 @@ void LSkatApp::initGUI()
   list.append(i18n("&Advanced"));
   list.append(i18n("&Hard"));
   ((KSelectAction *)ACTION("choose_level"))->setItems(list);
- 
-  (void)new KAction(i18n("Select &Carddeck..."), 0, this, SLOT(slotOptionsCardDeck()),
+
+  (void)new KAction(i18n("Select &Card Deck..."), 0, this, SLOT(slotOptionsCardDeck()),
                       actionCollection(), "select_carddeck");
-  ACTION("select_carddeck")->setStatusText(i18n("Configure carddecks..."));
-  ACTION("select_carddeck")->setWhatsThis(i18n("Choose how the cards should look like."));
+  ACTION("select_carddeck")->setStatusText(i18n("Configure card decks..."));
+  ACTION("select_carddeck")->setWhatsThis(i18n("Choose how the cards should look."));
 
   (void)new KAction(i18n("Change &Names..."), 0, this, SLOT(slotOptionsNames()),
                       actionCollection(), "change_names");
@@ -245,10 +225,8 @@ void LSkatApp::initGUI()
   connect(actionCollection(), SIGNAL(actionStatusText(const QString &)), SLOT(slotStatusMsg(const QString &)));
   connect(actionCollection(), SIGNAL(clearStatusText()), SLOT(slotClearStatusMsg()));
 
-  KHelpMenu *helpMenu = new KHelpMenu(this, 0, true, actionCollection());
-  connect( helpMenu, SIGNAL(showAboutApplication()), this, SLOT(slotHelpAbout()));
-
-  
+  KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+actionCollection());
 }
 
 
@@ -258,17 +236,11 @@ void LSkatApp::initStatusBar()
   // STATUSBAR
   // statusBar()->setInsertOrder(KStatusBar::RightToLeft);
   statusBar()->insertItem(i18n("This leaves space for the mover"),ID_STATUS_MOVER,0,true);
-  statusBar()->insertItem(i18n("23:45"),ID_STATUS_TIME,0,true);
   statusBar()->insertItem(i18n("Ready"), ID_STATUS_MSG);
 
-  slotStatusTime();
   slotStatusMover(i18n("(c) Martin Heni   "));
-  slotStatusMsg(i18n("Welcome to Lieutnant Skat"));
+  slotStatusMsg(i18n("Welcome to Lieutenant Skat"));
 
-  // status bar clock
-  statusTimer=new QTimer(this);
-  connect(statusTimer,SIGNAL(timeout()),this,SLOT(slotStatusTimer()));
-  statusTimer->start(10000,false);
   // computer move timer
   procTimer=new QTimer(this);
   connect(procTimer,SIGNAL(timeout()),this,SLOT(slotProcTimer()));
@@ -289,7 +261,7 @@ void LSkatApp::initView()
   view = new LSkatView(this);
   doc->addView(view);
   setCentralWidget(view);
-  setCaption(i18n("Lieutnant Skat"));
+  setCaption(i18n("Lieutenant Skat"));
 }
 
 void LSkatApp::enableAction(const char *s)
@@ -299,7 +271,7 @@ void LSkatApp::enableAction(const char *s)
     KAction *act=actionCollection()->action(s);
     if (act) act->setEnabled(true);
   }
-    
+
 }
 void LSkatApp::disableAction(const char *s)
 {
@@ -315,30 +287,6 @@ LSkatDoc *LSkatApp::getDocument() const
   return doc;
 }
 
-void LSkatApp::saveOptions()
-{
-  config->setGroup("General Options");
-  config->writeEntry("Geometry", size());
-  config->writeEntry("Show Statusbar",statusBar()->isVisible());
-  doc->WriteConfig(config);
-}
-
-
-void LSkatApp::readOptions()
-{
-  config->setGroup("General Options");
-  bool bViewStatusbar = config->readBoolEntry("Show Statusbar", true);
-  ((KToggleAction *)ACTION("show_statusbar"))->setChecked(bViewStatusbar);
-  if(!bViewStatusbar) statusBar()->hide();
-
-  QSize size=config->readSizeEntry("Geometry");
-  if(!size.isEmpty())
-  {
-    resize(size);
-  }
-  doc->ReadConfig(config);
-}
-
 void LSkatApp::saveProperties(KConfig *_cfg)
 {
   if(doc->getTitle()!=i18n("Untitled") && !doc->isModified())
@@ -348,7 +296,7 @@ void LSkatApp::saveProperties(KConfig *_cfg)
   else
   {
     QString filename=doc->getAbsFilePath();
-    _cfg->writeEntry("filename", filename);
+    _cfg->writePathEntry("filename", filename);
     _cfg->writeEntry("modified", doc->isModified());
 
     QString tempname = kapp->tempSaveName(filename);
@@ -359,7 +307,7 @@ void LSkatApp::saveProperties(KConfig *_cfg)
 
 void LSkatApp::readProperties(KConfig* _cfg)
 {
-  QString filename = _cfg->readEntry("filename", QCString(""));
+  QString filename = _cfg->readPathEntry("filename");
   bool modified = _cfg->readBoolEntry("modified", false);
   if(modified)
   {
@@ -385,7 +333,7 @@ void LSkatApp::readProperties(KConfig* _cfg)
   }
 
   //QString caption=kapp->caption();
-  setCaption(i18n("Lieutnant Skat"));
+  setCaption(i18n("Lieutenant Skat"));
 }
 
 bool LSkatApp::queryClose()
@@ -396,7 +344,7 @@ bool LSkatApp::queryClose()
 
 bool LSkatApp::queryExit()
 {
-  saveOptions();
+  doc->WriteConfig(config);
   return true;
 }
 
@@ -404,13 +352,11 @@ bool LSkatApp::queryExit()
 // SLOT IMPLEMENTATION
 /////////////////////////////////////////////////////////////////////
 
-
 void LSkatApp::slotFileStatistics()
 {
    QString message;
-
-   message=i18n("Do you really want to clear the all time\n"
-                "statistical data?\n");
+   message=i18n("Do you really want to clear the all time "
+                "statistical data?");
 
   if (KMessageBox::Yes==KMessageBox::questionYesNo(this,message))
   {
@@ -418,6 +364,7 @@ void LSkatApp::slotFileStatistics()
     doc->slotUpdateAllViews(0);
   }
 }
+
 /** send message */
 void LSkatApp::slotFileMessage()
 {
@@ -443,8 +390,6 @@ void LSkatApp::slotFileMessage()
   }
 }
 
-
-
 void LSkatApp::slotFileNew()
 {
   NewGame();
@@ -475,37 +420,26 @@ void LSkatApp::slotFileEnd()
   slotStatusNames();
 }
 
-
 void LSkatApp::slotFileQuit()
 {
-  saveOptions();
-  // close the first window, the list makes the next one the first again.
-  // This ensures that queryClose() is called on each window to ask for closing
-  KMainWindow* w;
-  if(memberList)
-  {
-    for(w=memberList->first(); w!=0; w=memberList->first())
-    {
-      // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
-      // the window and the application stay open.
-      if(w && !w->close())
-          break;
-    }
-  }
+  doc->WriteConfig(config);
+  if (view) view->close();
+  close();
+  kdDebug() << "slotFileQuit done"<<endl;
 }
 
-
 void LSkatApp::slotStartplayer()
 {
   int i=((KSelectAction *)ACTION("startplayer"))->currentItem();
   doc->SetStartPlayer(i);
   doc->UpdateViews(UPDATE_STATUS);
 }
+
 void LSkatApp::slotPlayer1By()
 {
   switch(((KSelectAction *)ACTION("player1"))->currentItem())
   {
-    case 0: 
+    case 0:
         slotPlayer1(KG_INPUTTYPE_INTERACTIVE);
     break;
     case 1:
@@ -516,11 +450,12 @@ void LSkatApp::slotPlayer1By()
     break;
   }
 }
+
 void LSkatApp::slotPlayer2By()
 {
   switch(((KSelectAction *)ACTION("player2"))->currentItem())
   {
-    case 0: 
+    case 0:
         slotPlayer2(KG_INPUTTYPE_INTERACTIVE);
     break;
     case 1:
@@ -531,6 +466,7 @@ void LSkatApp::slotPlayer2By()
     break;
   }
 }
+
 void LSkatApp::slotPlayer1(KG_INPUTTYPE i)
 {
   doc->SetPlayedBy(0,i);
@@ -547,6 +483,7 @@ void LSkatApp::slotPlayer1(KG_INPUTTYPE i)
   }
   doc->UpdateViews(UPDATE_STATUS);
 }
+
 void LSkatApp::slotPlayer2(KG_INPUTTYPE i)
 {
   doc->SetPlayedBy(1,i);
@@ -563,6 +500,7 @@ void LSkatApp::slotPlayer2(KG_INPUTTYPE i)
   }
   doc->UpdateViews(UPDATE_STATUS);
 }
+
 void LSkatApp::slotOptionsNames()
 {
   NameDlg *dlg=new NameDlg(this,QCString("Enter your name..."));
@@ -591,7 +529,6 @@ void LSkatApp::slotOptionsCardDeck()
     doc->SetCardDeckPath(s1,s2);
     doc->slotUpdateAllViews(0);
   }
-
 }
 
 void LSkatApp::slotLevel()
@@ -603,23 +540,11 @@ void LSkatApp::slotLevel()
   printf("Level set to %d\n",i);
 }
 
-void LSkatApp::slotViewStatusBar()
-{
-  ///////////////////////////////////////////////////////////////////
-  //turn Statusbar on or off
-  if (statusBar()->isVisible()) 
-  {
-    statusBar()->hide();
-  }
-  else
-  {
-    statusBar()->show();
-  }
-}
 void LSkatApp::slotClearStatusMsg()
 {
   slotStatusMsg(i18n("Ready"));
 }
+
 void LSkatApp::slotStatusMsg(const QString &text)
 {
   ///////////////////////////////////////////////////////////////////
@@ -636,21 +561,6 @@ void LSkatApp::slotStatusMover(const QString &text)
   statusBar()->changeItem(text, ID_STATUS_MOVER);
 }
 
-void LSkatApp::slotStatusTime()
-{
-  ///////////////////////////////////////////////////////////////////
-  // change status time permanently
-  QString s;
-  QTime now;
-
-  now=QTime::currentTime();
-  s=now.toString();
-  s.truncate(5);
-
-  statusBar()->clear();
-  statusBar()->changeItem(s, ID_STATUS_TIME);
-}
-
 
 void LSkatApp::slotStatusHelpMsg(const QString &text)
 {
@@ -659,7 +569,6 @@ void LSkatApp::slotStatusHelpMsg(const QString &text)
   statusBar()->message(text, 2000);
 }
 
-
 /** Triggers the processmove timer */
 void LSkatApp::slotProcTimer(void)
 {
@@ -671,10 +580,6 @@ void LSkatApp::slotProcTimer(void)
   */
 }
 
-/** Triggers the status timer */
-void LSkatApp::slotStatusTimer(void){
-  slotStatusTime();
-}
 /** Set the names in the mover field */
 void LSkatApp::slotStatusNames(){
 
@@ -682,7 +587,7 @@ void LSkatApp::slotStatusNames(){
   if (!doc->IsRunning()) msg=i18n("No game running");
   else
   {
-    msg=i18n("%1 to move ...").arg(doc->GetName(doc->GetCurrentPlayer()));
+    msg=i18n("%1 to move...").arg(doc->GetName(doc->GetCurrentPlayer()));
   }
   slotStatusMover(msg);
 }
@@ -697,18 +602,18 @@ void LSkatApp::NewGame()
   if (!res)
   {
     KMessageBox::error(this,
-      i18n("Cannot start player 1. Maybe the network connection\n"
-           "failed or the computer player process file is not\n"
-           "found.\n"));
+      i18n("Cannot start player 1. Maybe the network connection "
+           "failed or the computer player process file is not "
+           "found."));
     return ;
   }
   res=MakeInputDevice(1);
   if (!res)
   {
     KMessageBox::error(this,
-      i18n("Cannot start player 2. Maybe the network connection\n"
-           "failed or the computer player process file is not\n"
-           "found.\n"));
+      i18n("Cannot start player 2. Maybe the network connection "
+           "failed or the computer player process file is not "
+           "found."));
     return ;
   }
   // Remote game is started when receiving the start mesage .. not here!
@@ -750,6 +655,7 @@ bool LSkatApp::MakeInputDevice(int no)
   {
       QString host;
       short port;
+      QString Name;
       msg=new KEMessage;
       PrepareGame(msg);
       // Build new connection
@@ -758,8 +664,10 @@ bool LSkatApp::MakeInputDevice(int no)
         OptionsNetwork();
         port=doc->QueryPort();
         host=doc->QueryHost();
+	Name=doc->QueryName();
         msg->AddData(QCString("Port"),(short)port);
         msg->AddData(QCString("IP"),(char *)(host.latin1()));
+	msg->AddData(QCString("Name"),(const char *)(Name.utf8()));
         res=mInput->SetInputDevice(no,type,msg);
         if (!res)
         {
@@ -773,10 +681,10 @@ bool LSkatApp::MakeInputDevice(int no)
           }
           else
           {
-            s=i18n("Offering remote connection on port %1 ...").arg(port);
+            s=i18n("Offering remote connection on port %1...").arg(port);
           }
           progress=new QProgressDialog(s, i18n("Abort"), tim, this,0,true );
-          progress->setCaption(i18n("Lieutnant Skat"));
+          progress->setCaption(i18n("Lieutenant Skat"));
           for (j=0; j<tim; j++)
           {
             progress->setProgress( j );
@@ -839,22 +747,6 @@ bool LSkatApp::MakeInputDevice(int no)
   return res;
 }
 
-void LSkatApp::slotHelpAbout()
-{
-  slotStatusMsg(i18n("About the program..."));
-
-  EMovie *movie=new EMovie;
-  movie->frameDelay=70;
-  movie->frameArray=doc->mPixAnim;
-  movie->frameCnt=NO_OF_ANIM;
-  aboutDlg *dlg=new aboutDlg(this);
-  dlg->SetMovie(movie);
-  dlg->exec();
-  delete movie;
-  slotStatusMsg(i18n("Ready"));
-}
-
-
 void LSkatApp::OptionsNetwork()
 {
   int res;
@@ -862,9 +754,11 @@ void LSkatApp::OptionsNetwork()
   NetworkDlg *dlg=new NetworkDlg(this,QCString("Configure a network game..."));
   dlg->SetPort(doc->QueryPort());
   dlg->SetHost(doc->QueryHost());
+  dlg->SetName(doc->QueryName());
   res=dlg->exec();
   doc->SetPort(dlg->QueryPort());
   doc->SetHost(dlg->QueryHost());
+  doc->SetName(dlg->QueryName());
   delete dlg;
 }
 
@@ -883,18 +777,21 @@ void LSkatApp::slotPrepareProcessMove(KEMessage *msg)
     msg->AddData(QCString("KLogSendMsg"),"process.log");
   PrepareGame(msg);
 }
+
 void LSkatApp::slotPrepareRemoteMove(KEMessage *)
 {
   if (global_debug>3)
     printf("+++ main should prepare remote move\n");
   slotStatusMsg(i18n("Waiting for remote player..."));
 }
+
 void LSkatApp::slotPrepareInteractiveMove(KEMessage *)
 {
   if (global_debug>3)
     printf("+++ main should prepare interactive move\n");
   slotStatusMsg(i18n("Please make your move..."));
 }
+
 void LSkatApp::slotReceiveInput(KEMessage *msg,int )
 {
   /*
@@ -1051,6 +948,7 @@ void LSkatApp::MoveFinished()
     }
     slotStatusNames();
 }
+
 void LSkatApp::Move(int x,int y,int player,bool remote)
 {
   KEMessage *msg;
@@ -1085,7 +983,7 @@ void LSkatApp::Move(int x,int y,int player,bool remote)
   else if (res==-3)
   {
      KMessageBox::information(this,
-       i18n("Ehm, this move would not follow the rulebook.\n"
+       i18n("This move would not follow the rulebook.\n"
             "Better think again!\n"));
     return ;
   }
@@ -1100,9 +998,12 @@ void LSkatApp::Move(int x,int y,int player,bool remote)
     return ;
   }
 }
+
 void LSkatApp::PrepareGame(KEMessage *msg)
 {
-  if (!msg) return ;
+  if (!msg)
+    return;
+
   msg->AddData(QCString("Cards"),(char *)doc->GetCardP(),NO_OF_CARDS*sizeof(int));
   msg->AddData(QCString("Startplayer"),(short)doc->GetStartPlayer());
   msg->AddData(QCString("CurrentPlayer"),(short)doc->GetCurrentPlayer());
@@ -1120,9 +1021,11 @@ void LSkatApp::PrepareGame(KEMessage *msg)
   msg->AddData(QCString("Sc2"),(short)doc->GetScore(1));
   msg->AddData(QCString("Level"),(short)doc->GetComputerLevel());
 }
+
 void LSkatApp::ExtractGame(KEMessage *msg)
 {
-  if (!msg) return ;
+  if (!msg)
+    return;
   // Do we have to switch players?
   bool switchit;
   short remote;
